1.0.0 API documentation: number_precision.hpp Source File

| 1.0.0 API documentation

number_precision.hpp
Go to the documentation of this file.
1
15 #pragma once
16
17 // Dependency:
18 #include "../glm.hpp"
19 #include "../gtc/type_precision.hpp"
20
21 #ifndef GLM_ENABLE_EXPERIMENTAL
22 # error "GLM: GLM_GTX_number_precision is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it."
23 #elif GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
24 # pragma message("GLM: GLM_GTX_number_precision extension included")
25 #endif
26
27 namespace glm{
29 // Unsigned int vector types
30
33
35 // Float matrix types
36
37 typedef f32 f32mat1;
38 typedef f32 f32mat1x1;
39 typedef f64 f64mat1;
40 typedef f64 f64mat1x1;
41
43 }//namespace glm
44
45 #include "number_precision.inl"
glm::f32mat1
f32 f32mat1
Single-qualifier floating-point scalar. (from GLM_GTX_number_precision extension)
Definition: number_precision.hpp:37
glm::f64
double f64
Default 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:168
glm::f64mat1x1
f64 f64mat1x1
Double-qualifier floating-point scalar. (from GLM_GTX_number_precision extension)
Definition: number_precision.hpp:40
glm::f32
float f32
Default 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:152
glm::f32mat1x1
f32 f32mat1x1
Single-qualifier floating-point scalar. (from GLM_GTX_number_precision extension)
Definition: number_precision.hpp:38
glm::f64mat1
f64 f64mat1
Double-qualifier floating-point scalar. (from GLM_GTX_number_precision extension)
Definition: number_precision.hpp:39